summaryrefslogtreecommitdiff
path: root/sw/inc
diff options
context:
space:
mode:
authorNoel Grandin <noel.grandin@collabora.co.uk>2024-08-05 11:59:02 +0200
committerNoel Grandin <noel.grandin@collabora.co.uk>2024-08-07 12:05:53 +0200
commited172f76005d6e7b861b51199b5d897254b0c76b (patch)
treea5e58a9d6a6ca24a7dd8ce6aca740a7d75c98c35 /sw/inc
parent49bca657d7d66ce75a49d2912d1fc86b3e89bcc4 (diff)
simplify IMark hierarchy (11)
The only thing using findFirstBookmarkNotStartsBefore is code that is only interested in Bookmark's, so change the name and return type, and use the m_vBookmarks vector, which is much more efficient. Change-Id: I7f7e6f98b9b7851756c06e57f1cd18cee98713d6 Reviewed-on: https://gerrit.libreoffice.org/c/core/+/171565 Tested-by: Jenkins Reviewed-by: Noel Grandin <noel.grandin@collabora.co.uk>
Diffstat (limited to 'sw/inc')
-rw-r--r--sw/inc/IDocumentMarkAccess.hxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/sw/inc/IDocumentMarkAccess.hxx b/sw/inc/IDocumentMarkAccess.hxx
index 60b2928067a1..8d20ee09a845 100644
--- a/sw/inc/IDocumentMarkAccess.hxx
+++ b/sw/inc/IDocumentMarkAccess.hxx
@@ -231,12 +231,12 @@ class IDocumentMarkAccess
*/
virtual const_iterator findMark(const OUString& rMark) const =0;
/** Find the first Mark that does not start before.
@returns
an iterator pointing to the mark, or pointing to getAllMarksEnd() if nothing was found.
*/
- virtual const_iterator findFirstMarkNotStartsBefore(const SwPosition& rPos) const =0;
+ virtual std::vector<sw::mark::Bookmark*>::const_iterator findFirstBookmarkNotStartsBefore(const SwPosition& rPos) const =0;
// interface Bookmarks (BOOKMARK, CROSSREF_NUMITEM_BOOKMARK, CROSSREF_HEADING_BOOKMARK )
@@ -231,12 +231,12 @@ class IDocumentMarkAccess
*/
virtual const_iterator findMark(const OUString& rMark) const =0;
- /** Find the first Mark that does not start before.
+ /** Find the first Bookmark that does not start before.
an iterator pointing to the mark, or pointing to getAllMarksEnd() if nothing was found.